***Data preparation code for the analysis in Dahl et al. (2021) "Caught between Cultures: Unintended Consequences of Improving Opportunity for Immigrant Girls"
clear
clear matrix
capture log close
set more off

* Enter your global pathway to the project in the following line instead of ... *

global DataR "...\Replication\Data\Raw"
global DataC "...\Replication\Data\Clean"

/********************** DATASET **********************************/
use "$DataR\data_analysis", clear


* Migration Background 
gen Mig_Status = 0 if Born_in_Germany_Mother==1 & Born_in_Germany_Father==1
replace Mig_Status = 1 if Born_in_Germany_Mother ==0 & Born_in_Germany_Father==0
label var Mig_Status "Migration background"
label define mig 0 "Both parents are born in Germany" 1 "Both parents are foreign-born"
label value Mig_Status mig

* Month of Birth, Week of Birth, Day of Birth 
gen birth =ym(Year_of_Birth,Month_of_Birth)
gen bmonth = birth - 467
gen Bmonth_centered = bmonth-13
label var Bmonth_centered   "Birth month(=0 at cutoff month)"

gen bday = mdy(Month_of_Birth,Day_of_Birth,Year_of_Birth)
gen bday_c=bday
format bday_c %td
gen Bday_centered = bday - 14610
label var Bday_centered    "Birth day (=0 at cutoff day)"

gen bweek = wofd(bday_c)
gen Bweek_centered = bweek-2080
label var Bweek_centered    "Birth week (=0 at cutoff week)"


*** DiD Categories/Treatment Variables ****

** Basic DiD Model: Treatment group = second generation immigrants; Control group = natives

* Dummy for whether a child was born in the months after January 1, 2000
gen Post = 0 if Year_of_Birth<2000
replace Post = 1 if Year_of_Birth>=2000
label var Post "Born after the cutoff date"

* Dummy for whether child is a second-generation immigrant versus a native
gen Immig=0 if Mig_Status==0
replace Immig=1 if Mig_Status == 1 & Born_in_Germany==1 & (Origin_Mother!=12 | Origin_Father!=12)
label var Immig   "2nd generation Immig (=1), native (=0)"

* Interaction Immig*Post
gen Treat=Post*Immig
label var Treat "Interaction Immig*Post"

* Muslim Dummy for DiD analyses by religious background (Tables 5 to 10)
gen muslim=(Rel_affiliation==4) if Rel_affiliation!=.
label var muslim   "Muslim (dummy)"  


** DiD Robustness (Table 3, Col 3): Treatment group = second generation immigrants; Control group = first generation immigrants
gen Immig_first=1 if Immig==1
replace Immig_first=0 if Born_in_Germany==0 & Mig_Status==1
label var Immig_first   "2nd generation Immig (=1), 1st generation (=0)"
gen Treat_first=Post*Immig_first
label var Treat_first "Interaction Immig_first*Post"

** DiD Robustness (Table 3, Col 4): Treatment group = second generation immigrants; Control group = natives and first generation immigrants
gen Immig_FirstNatives=1 if Immig==1
replace Immig_FirstNatives=0 if Born_in_Germany==0 & Mig_Status==1
replace Immig_FirstNatives=0 if Mig_Status==0
label var Immig_FirstNatives "2nd generation Immig (=1), 1st generation Immig & natives (=0)"
gen Treat_FirstNatives=Post*Immig_FirstNatives
label var Treat_FirstNatives "Interaction Immig_FirstNatives*Post"

** DiD Robustness (Table A4): Triple Interactions
gen Immig_Girl=Immig*Female
label var Immig_Girl "Interaction Immig*Girl"
gen Post_Girl=Post*Female
label var Post_Girl   "Interaction Post*Girl"
gen Treat_Girl=Post*Immig*Female
label var Treat_Girl   "Interaction Treat*Girl"


** Did Robustness (Table A6, Col 2): Mother and Father from Turkey or Middle East 

gen dad_mcountry=(Origin_Father==8|Origin_Father==2)
replace dad_mcountry=. if Origin_Father==.
gen mom_mcountry=(Origin_Mother==8|Origin_Mother==2)
replace mom_mcountry=. if Origin_Mother==.
gen both_mcountry=mom_mcountry & dad_mcountry & mom_mcountry!=.
label var both_mcountry "Both mother and father from Turkey or Middle East"

** DiD Mechanisms (Table 10, Cols 5-8): Younger brothers, younger sisters

gen Broth_young=Brothers_no-Older_brothers
gen Sis_young=Sisters_no-Older_sisters
label var Broth_young "Younger brother(s) (dummy)"
label var Sis_young "Younger sister(s) (dummy)"


*** Control Variables ***

* City Size Fixed Effects
gen City_small=0
replace City_small=1 if City_size<100000
label var City_small "City Size<100,000" 

* Parents' Education
gen Edum_l=(Education_Mother==1|Education_Mother==2)
gen Edum_m=(Education_Mother==3)
gen Edum_h=(Education_Mother==4|Education_Mother==5)
gen Edum_miss=(Education_Mother==6|Education_Mother==7|Education_Mother==8)
gen Eduf_l=(Education_Father==1|Education_Father==2)
gen Eduf_m=(Education_Father==3)
gen Eduf_h=(Education_Father==4|Education_Father==5)
gen Eduf_miss=(Education_Father==6|Education_Father==7|Education_Father==8)
label var Edum_l "Education Mother: Low"
label var Edum_m "Education Mother: Intermediate"
label var Edum_h "Education Mother: High"
label var Edum_miss "Education Mother: Unknown"
label var Eduf_l "Education Father: Low"
label var Eduf_m "Education Father: Intermediate"
label var Eduf_h "Education Father: High"
label var Eduf_miss "Education Father: Unknown"


*** Variables for Descriptive Statistics for Religious Affiliation and Country of Origin (Table A2) ***

* Respondent's Religion
gen Religion=1 if Rel_affiliation==1
replace Religion=2 if Rel_affiliation==2
replace Religio=3 if Rel_affiliation==4
replace Religion=4 if Rel_affiliation==6
replace Religion=5 if Rel_affiliation==3 | Rel_affiliation==5 | Rel_affiliation==.
tab Religion, gen(Religion)
rename Religion1 Catholic
rename Religion2 Protestant
rename Religion3 Muslim
rename Religion4 None
rename Religion5 Other_Missing
label var Catholic   "Catholic (dummy)" 
label var Protestant "Protestant (dummy)"  
label var Muslim   "Muslim (dummy)"
label var None   "No Religion (dummy)"
label var Other_Missing   "Other Religion or Missing(dummy)"

* Mother's Region of Birth

tab Origin_Mother, gen(origin)
rename origin1 Germany
rename origin2 Turkey
rename origin3 Balcan
rename origin4 Eastern_Europe
rename origin5 Post_Soviet
rename origin6 Southern_Europe
rename origin7 Central_Northern_Europe
rename origin8 Middle_East
rename origin9 Asia
rename origin10 Africa
rename origin11 Rest_of_World
rename origin12 Unidentified
label var Germany   "Mother's country/region of birth: Germany "
label var Turkey   "Mother's country/region of birth: Turkey "
label var Balcan   "Mother's country/region of birth: Balcan countries"
label var Eastern_Europe   "Mother's country/region of birth: Easter Europe "
label var Post_Soviet   "Mother's country/region of birth: Post Soviet countries"
label var Southern_Europe   "Mother's country/region of birth: Southern Europe"
label var Central_Northern_Europe   "Mother's country/region of birth: Central & Northern Europe"
label var Middle_East   "Mother's country/region of birth: Middle East"
label var Asia   "Mother's country/region of birth: Asia"
label var Afric   "Mother's country/region of birth: Africa"
label var Rest_of_World   "Mother's country/region of birth: Rest"
label var Unidentified   "Mother's country/region of birth: Unknown"


*** Outcome Variables ***

*Life Satisfaction (Tables 1-3, Table 5, Table A4, Table A6)

sum Lifesatisfaction if Immig==0
gen mean_ls=r(mean)
gen std_ls=r(sd)
gen z_ls=(Lifesatisfaction-mean_ls)/std_ls


*Standardized components of the index of self-esteem (Table 4, Cols 2-6)

sum Selfesteem_a if Immig==0
return list
gen mean_a=r(mean)
gen std_a=r(sd)
gen se_a=(Selfesteem_a-mean_a)/std_a
drop mean_a std_a

sum Selfesteem_b if Immig==0
return list
gen mean_c=r(mean)
gen std_c=r(sd)
gen se_c=(Selfesteem_b-mean_c)/std_c
drop mean_c std_c

sum Selfesteem_c if Immig==0
return list
gen mean_d=r(mean)
gen std_d=r(sd)
gen se_d=(Selfesteem_c-mean_d)/std_d
drop std_d mean_d

sum Selfesteem_d if Immig==0
return list
gen mean_g=r(mean)
gen std_g=r(sd)
gen se_g=(Selfesteem_d-mean_g)/std_g
drop std_g mean_g

sum Selfesteem_e if Immig==0
return list
gen mean_j=r(mean)
gen std_j=r(sd)
gen se_j=(Selfesteem_e-mean_j)/std_j
drop std_j mean_j

* Index of self-esteem (Table 4, Col 1)

gen SE_pos_index=1/5*(se_a+se_c+se_d+se_g+se_j)


* Index of social participation (Table 6, Cols 1-2)

gen theater=0
replace theater=1 if Extracurricular_a==1
gen orchestra=0
replace orchestra=1 if Extracurricular_b==1
gen sport=0
replace sport=1 if Extracurricular_c==1
gen newspaper=0
replace newspaper=1 if Extracurricular_d==1

egen index_participation=rowtotal(theater orchestra sport newspaper)


* Index of friendship support (Table 6, Cols 3-4)

sum Friendshipsupport_a if Immig==0 & Friendshipsupport_a!=. & Friendshipsupport_b!=. 
return list
gen mean_a=r(mean)  if Friendshipsupport_a!=. & Friendshipsupport_b!=. 
gen std_a=r(sd)  if Friendshipsupport_a!=. & Friendshipsupport_b!=. 
gen y_a=(Friendshipsupport_a-mean_a)/std_a  if Friendshipsupport_a!=. & Friendshipsupport_b!=. 

sum Friendshipsupport_b if Immig==0 &  Friendshipsupport_a!=. & Friendshipsupport_b!=. 
return list
gen mean_b=r(mean)  if Friendshipsupport_a!=. & Friendshipsupport_b!=. 
gen std_b=r(sd)  if Friendshipsupport_a!=. & Friendshipsupport_b!=. 
gen y_b=(Friendshipsupport_b-mean_b)/std_b   if Friendshipsupport_a!=. & Friendshipsupport_b!=. 

gen Support=1/2*(y_a+y_b)  if Friendshipsupport_a!=. & Friendshipsupport_b!=. 
drop y_a y_b mean_a mean_b std_a std_b


* Index of loneliness (Table 6, Cols 5-6)

gen Lonely_a_alt=7-Lonely_a if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
sum Lonely_a_alt if Immig==0 & Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
return list
gen mean_a=r(mean) if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
gen std_a=r(sd) if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
gen y_a=(Lonely_a_alt-mean_a)/std_a if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.

sum Lonely_b if Immig==0 & Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
return list
gen mean_b=r(mean) if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
gen std_b=r(sd) if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
gen y_b=(Lonely_b-mean_b)/std_b if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.

sum Lonely_c if Immig==0 & Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
return list
gen mean_c=r(mean) if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
gen std_c=r(sd) if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.
gen y_c=(Lonely_c-mean_c)/std_c if Lonely_b!=. & Lonely_c!=. & Lonely_a!=.

gen Lonely=1/3*(y_a+y_b+y_c)
drop y_a y_b y_c mean_a mean_b mean_c std_a std_b std_c


* Self-identify as German (Table 6, Cols 7-8)

gen German=0
replace German=1 if Selfidentification<=2


* No schooling support from parents (Table 7, Cols 1-2) 

gen lives_with_one_or_both_parents=0
replace lives_with_one_or_both_parents=1 if Living_Arrangement<=3

gen Parents_Invest=.
replace Parents_Invest=1 if Schoolingsupport<=3
replace Parents_Invest=0 if Schoolingsupport==4

gen Invest_reg=Parents_Invest*lives_with_one_or_both_parents

gen Noinvest_reg=.
replace Noinvest_reg=1 if Invest_reg==0
replace Noinvest_reg=0 if Invest_reg==1


* No schooling support from parents and low academic achievement (Table 7, Cols 3-4)

gen Average_Grade=(Grade_German+Grade_Math)/2
gen Good_Grades=1 if Average_Grade<3
replace Good_Grades=0 if Average_Grade>=3 & Average_Grade<=5

gen Low_Grades=1 if Good_Grades==0
replace Low_Grades=0 if Good_Grades==1

gen Noinvest_reg_Low=Noinvest_reg*Low_Grades


* Never speaks German with one or both parents (Table 7, Cols 5-6)

gen nogerman_mother=.
replace nogerman_mother=1 if Language_with_Mother ==4
replace nogerman_mother=0 if Language_with_Mother <4

gen nogerman_father=.
replace nogerman_father=1 if Language_with_Father ==4
replace nogerman_father=0 if Language_with_Father <4

gen nogerman_parents_either=.
replace nogerman_parents_either=1 if nogerman_mother==1 | nogerman_father==1
replace nogerman_parents_either=0 if nogerman_mother==0 & nogerman_father==0

gen Nogerman_reg=nogerman_parents_either*lives_with_one_or_both_parents


* Aspires to pursue tertiary education (Table 8, Cols 1-2)

gen tertiary=0 if Educ_Aspiration_a!=. & Educ_Aspiration_b!=.
replace tertiary=1 if Educ_Aspiration_a==1|Educ_Aspiration_b==1


* High vs. low odds of achieving educational aspirations (Table 8, Cols 3-4) 

gen Prob_training=1 if Prob_Success_Education!=.
replace Prob_training=0 if Prob_Success_Education<=50

gen Prob_job=1 if Prob_Success_Job!=.
replace Prob_job=0 if Prob_Success_Job<=50

gen Prob_success=0 if Prob_training!=. & Prob_job!=.
replace Prob_success=1 if Prob_training==1 & Prob_job==1

* Disillusionment: high aspirations and low success odss (Table 8, Cols 5-6) 

gen joint=0 if Prob_training!=. & tertiary!=.
replace joint=1 if Prob_training==0 & tertiary==1

gen joint_grades_invest=0 if Invest_reg!=. & Good_Grades!=.
replace joint_grades_invest=1 if Invest_reg==0 & Good_Grades==0

* No schooling support from parents and disillusionment (Table 8, Cols 7-8)

gen joint_disill_invest=0 if joint!=. & Invest_reg!=.
replace joint_disill_invest=1 if joint==1 & Invest_reg==0


* Expected change in life satisfaction 5 years in the future (Table 9)

gen Change_LS=Lifesatisfaction_5y-Lifesatisfaction
sum Change_LS if Immig==0
return list
gen mean_d_ls=r(mean)
gen std_d_ls=r(sd)
gen increaseLS=(Change_LS-mean_d_ls)/std_d_ls


* Foreigners have to do a great deal to be recognized (Table 10, Cols 1-2)

sum Foreigners_recognition if Immig==0
return list
gen mean_b=r(mean)
gen std_b=r(sd)
gen Workharder=(Foreigners_recognition-mean_b)/std_b
drop mean_b std_b

* Need to be German to succeed (Table 10, Cols 3-4)

gen Germansucceed=0 if Success_in_Germany<=2
replace Germansucceed=1 if Success_in_Germany==3 | Success_in_Germany==4


*Standardized GPA (Table A7)

sum Average_Grade if Average_Grade!=. & Immig==0 
return list
gen mean_grades=r(mean)
gen std_grades=r(sd)
gen gpa_main=(Average_Grade-mean_grades)/std_grades


*** Label variables ***

label var z_ls  "Standardized Life Satisfaction"
label var increaseLS "Increase in Future Life Satisfaction (std)"
label var Change_LS "Increase in Future Life Satisfaction"


label var SE_pos_index "Self Esteem Index (std)"
label var se_a "Satisfied with oneself (std)"
label var se_c "I have good qualities (std)"
label var se_d "As good as others (std)"
label var se_g "I am worthy (std)"
label var se_j  "Positive attitude towards onself (std)"

label var index_participation "Index of social participation (std)"
label var Support "Index of friendship support (std)"
label var Lonely   "Index of loneliness (std)"
label var German   "Self-identify as German (dummy)"

label var Noinvest_reg  "No schooling support from parents (dummy)" 
label var Noinvest_reg_Low   "No schooling support and low academic achievment (dummy)"
label var Nogerman_reg "Never sepaks German with one or both parents (dummy)"  
label var tertiary   "Aspires to tertiary education (dummy)"
label var Prob_training   "High vs. low odds of achieving educational aspirations (dummy)"
label var joint   "Disillusionment"
label var joint_disill_invest "No schooling support from parents and disillusionment"

label var Workharder "Foreigners need to work harder for recognition (std)"  
label var Germansucceed  "Need to be German to succeed (dummy)" 

label var gpa_main "Grade point average in Math and German (std)"

*** Drop redundant variables *** 

drop birth bmonth bday bday_c bweek dad_mcountry mom_mcountry Religion mean_ls std_ls theater orchestra sport newspaper Lonely_a_alt lives_with_one_or_both_parents Parents_Invest Invest_reg Average_Grade Good_Grades Low_Grades nogerman_mother nogerman_father nogerman_parents_either Prob_job Prob_success joint_grades_invest mean_d_ls std_d_ls mean_grades std_grades


save "$DataC\data_for_estimation", replace






